==> aravis-0.5.0.tar.xz: aravis-0.5.0/src/arvenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef ARV_ENUM_TYPES_H
#define ARV_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "arvenums.h" */

#define ARV_TYPE_GC_NAME_SPACE	(arv_gc_name_space_get_type())
GType arv_gc_name_space_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_ACCESS_MODE	(arv_gc_access_mode_get_type())
GType arv_gc_access_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_CACHABLE	(arv_gc_cachable_get_type())
GType arv_gc_cachable_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_AUTO	(arv_auto_get_type())
GType arv_auto_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_ACQUISITION_MODE	(arv_acquisition_mode_get_type())
GType arv_acquisition_mode_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdebug.h" */

#define ARV_TYPE_DEBUG_LEVEL	(arv_debug_level_get_type())
GType arv_debug_level_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdomnode.h" */

#define ARV_TYPE_DOM_NODE_TYPE	(arv_dom_node_type_get_type())
GType arv_dom_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcpropertynode.h" */

#define ARV_TYPE_GC_PROPERTY_NODE_TYPE	(arv_gc_property_node_type_get_type())
GType arv_gc_property_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcregisternode.h" */

#define ARV_TYPE_GC_SIGN	(arv_gc_sign_get_type())
GType arv_gc_sign_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_REGISTER_NODE_TYPE	(arv_gc_register_node_type_get_type())
GType arv_gc_register_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdevice.h" */

#define ARV_TYPE_DEVICE_STATUS	(arv_device_status_get_type())
GType arv_device_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvstream.h" */

#define ARV_TYPE_STREAM_CALLBACK_TYPE	(arv_stream_callback_type_get_type())
GType arv_stream_callback_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvbuffer.h" */

#define ARV_TYPE_BUFFER_STATUS	(arv_buffer_status_get_type())
GType arv_buffer_status_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_BUFFER_PAYLOAD_TYPE	(arv_buffer_payload_type_get_type())
GType arv_buffer_payload_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvchunkparser.h" */

#define ARV_TYPE_CHUNK_PARSER_STATUS	(arv_chunk_parser_status_get_type())
GType arv_chunk_parser_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvstream.h" */

#define ARV_TYPE_GV_STREAM_SOCKET_BUFFER	(arv_gv_stream_socket_buffer_get_type())
GType arv_gv_stream_socket_buffer_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GV_STREAM_PACKET_RESEND	(arv_gv_stream_packet_resend_get_type())
GType arv_gv_stream_packet_resend_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvcp.h" */

#define ARV_TYPE_GVCP_PACKET_TYPE	(arv_gvcp_packet_type_get_type())
GType arv_gvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVCP_COMMAND	(arv_gvcp_command_get_type())
GType arv_gvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvsp.h" */

#define ARV_TYPE_GVSP_PACKET_TYPE	(arv_gvsp_packet_type_get_type())
GType arv_gvsp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVSP_CONTENT_TYPE	(arv_gvsp_content_type_get_type())
GType arv_gvsp_content_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVSP_PAYLOAD_TYPE	(arv_gvsp_payload_type_get_type())
GType arv_gvsp_payload_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvuvcp.h" */

#define ARV_TYPE_UVCP_PACKET_TYPE	(arv_uvcp_packet_type_get_type())
GType arv_uvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_UVCP_COMMAND	(arv_uvcp_command_get_type())
GType arv_uvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvuvsp.h" */

#define ARV_TYPE_UVSP_PACKET_TYPE	(arv_uvsp_packet_type_get_type())
GType arv_uvsp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_UVSP_PAYLOAD_TYPE	(arv_uvsp_payload_type_get_type())
GType arv_uvsp_payload_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* ARV_ENUM_TYPES_H */

/* Generated data ends here */

==> aravis-0.5.1.tar.xz: aravis-0.5.1/src/arvenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef ARV_ENUM_TYPES_H
#define ARV_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "arvenums.h" */

#define ARV_TYPE_GC_NAME_SPACE	(arv_gc_name_space_get_type())
GType arv_gc_name_space_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_ACCESS_MODE	(arv_gc_access_mode_get_type())
GType arv_gc_access_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_CACHABLE	(arv_gc_cachable_get_type())
GType arv_gc_cachable_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_AUTO	(arv_auto_get_type())
GType arv_auto_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_ACQUISITION_MODE	(arv_acquisition_mode_get_type())
GType arv_acquisition_mode_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdebug.h" */

#define ARV_TYPE_DEBUG_LEVEL	(arv_debug_level_get_type())
GType arv_debug_level_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdomnode.h" */

#define ARV_TYPE_DOM_NODE_TYPE	(arv_dom_node_type_get_type())
GType arv_dom_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgc.h" */

#define ARV_TYPE_GC_ERROR	(arv_gc_error_get_type())
GType arv_gc_error_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcpropertynode.h" */

#define ARV_TYPE_GC_PROPERTY_NODE_TYPE	(arv_gc_property_node_type_get_type())
GType arv_gc_property_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcregisternode.h" */

#define ARV_TYPE_GC_SIGN	(arv_gc_sign_get_type())
GType arv_gc_sign_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_REGISTER_NODE_TYPE	(arv_gc_register_node_type_get_type())
GType arv_gc_register_node_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvdevice.h" */

#define ARV_TYPE_DEVICE_STATUS	(arv_device_status_get_type())
GType arv_device_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvstream.h" */

#define ARV_TYPE_STREAM_CALLBACK_TYPE	(arv_stream_callback_type_get_type())
GType arv_stream_callback_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvbuffer.h" */

#define ARV_TYPE_BUFFER_STATUS	(arv_buffer_status_get_type())
GType arv_buffer_status_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_BUFFER_PAYLOAD_TYPE	(arv_buffer_payload_type_get_type())
GType arv_buffer_payload_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvchunkparser.h" */

#define ARV_TYPE_CHUNK_PARSER_STATUS	(arv_chunk_parser_status_get_type())
GType arv_chunk_parser_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvstream.h" */

#define ARV_TYPE_GV_STREAM_SOCKET_BUFFER	(arv_gv_stream_socket_buffer_get_type())
GType arv_gv_stream_socket_buffer_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GV_STREAM_PACKET_RESEND	(arv_gv_stream_packet_resend_get_type())
GType arv_gv_stream_packet_resend_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvcp.h" */

#define ARV_TYPE_GVCP_PACKET_TYPE	(arv_gvcp_packet_type_get_type())
GType arv_gvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVCP_COMMAND	(arv_gvcp_command_get_type())
GType arv_gvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvsp.h" */

#define ARV_TYPE_GVSP_PACKET_TYPE	(arv_gvsp_packet_type_get_type())
GType arv_gvsp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVSP_CONTENT_TYPE	(arv_gvsp_content_type_get_type())
GType arv_gvsp_content_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVSP_PAYLOAD_TYPE	(arv_gvsp_payload_type_get_type())
GType arv_gvsp_payload_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvuvcp.h" */

#define ARV_TYPE_UVCP_PACKET_TYPE	(arv_uvcp_packet_type_get_type())
GType arv_uvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_UVCP_COMMAND	(arv_uvcp_command_get_type())
GType arv_uvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvuvsp.h" */

#define ARV_TYPE_UVSP_PACKET_TYPE	(arv_uvsp_packet_type_get_type())
GType arv_uvsp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_UVSP_PAYLOAD_TYPE	(arv_uvsp_payload_type_get_type())
GType arv_uvsp_payload_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* ARV_ENUM_TYPES_H */

/* Generated data ends here */
